@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: connection
 version: 0.2.5
-id: connection-0.2.5-bf0be896e72357cc1edd4c2cf71b9005
-key: conne_Hu8yccNGqTDG5ozvmhBUKc
+id: connection-0.2.5-8679766890f442068d557b54b4535c5d
+key: conne_2HpkLSytjYZIvMKKT5MIkR
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/connection-0.2.5
-hs-libraries: HSconnection-0.2.5-Hu8yccNGqTDG5ozvmhBUKc
+hs-libraries: HSconnection-0.2.5-2HpkLSytjYZIvMKKT5MIkR
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
@@ -36,11 +36,11 @@ depends:
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
-    tls-1.3.4-a2c9d78849a8c3879b7fc9c50ab96b48
-    x509-1.6.3-a26654b2694b0222cea24c9509df18b8
-    x509-store-1.6.1-de9ae6187f4cf8a9fc0d902dd3099237
-    x509-system-1.6.3-ea9efa0bc30d005c03db48465026b9c4
-    x509-validation-1.6.3-aff871fef370c18650430c4d940ddd0e
+    tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
+    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
+    x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
+    x509-system-1.6.3-6ba9c22edd2365d0a08eb6f448807838
+    x509-validation-1.6.3-47849fe369535aae4a3b7e2d99568d36
 haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
 haddock-html: /usr/share/doc/haskell-connection/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
